import 'package:flutter/material.dart';
import 'package:login_screen/bottomnavigationbar/page1.dart';
import 'package:login_screen/bottomnavigationbar/page2.dart';
import 'package:login_screen/bottomnavigationbar/page3.dart';
import 'package:login_screen/bottomnavigationbar/page4.dart';
import 'package:login_screen/bottomnavigationbar/page5.dart';
import 'package:login_screen/bottomnavigationbar/page6.dart';
import 'package:login_screen/bottomnavigationbar/page7.dart';
import 'package:login_screen/bottomnavigationbar/page8.dart';

class NavBar9 extends StatefulWidget {
  const NavBar9({Key? key}) : super(key: key);
  @override
  State<NavBar9> createState() => _NavBar9State();
}
class _NavBar9State extends State<NavBar9> with TickerProviderStateMixin {
  int _selectedIndex = 0;
  List pages = [
    const Page5(),
    const Page6(),
    const Page7(),
    const Page8(),
  ];
  List labels=[
    'Home',
    'Message',
    'Cart',
    'Profile'
  ];
  List icon=[
    Icons.home,
    Icons.message,
    Icons.shopping_cart,
    Icons.person
  ];

  late AnimationController controller;
  late Animation<double> animation;
  late double position;

  @override
  void initState(){
    controller=AnimationController(vsync: this,duration: const Duration(milliseconds: 400));
    animation=CurvedAnimation(parent: controller, curve: Curves.easeOutBack);
    position=0;
    super.initState();
  }


  double getEndPosition(int index){
    return index*MediaQuery.of(context).size.width/4;
  }

  void animateBar(int index){
    animation=Tween(begin: position, end: getEndPosition(index)).animate(
        CurvedAnimation(parent: controller, curve: Curves.easeOutBack));
    controller.forward().then((value){
      position=getEndPosition(index);
      controller.dispose();
      controller=AnimationController(vsync: this,duration: const Duration(milliseconds: 400) );
    });
  }



  @override
  Widget build(BuildContext context) {
    Size screenSize = MediaQuery.of(context).size;
    const myColor=Colors.deepOrange;
    return Scaffold(
      extendBody: true,
      body: pages[_selectedIndex],
      bottomNavigationBar: Stack(
        alignment: Alignment.bottomCenter, // Align children to the bottom of the Stack
        children: [
          AnimatedBuilder(
            animation: controller,
            builder: (context, child){
              return ClipPath(
                clipper: MyClipper(x: animation.value),
                child: Container(
                  height: screenSize.height * 0.067,
                  width: screenSize.width,
                  decoration: BoxDecoration(
                    gradient: LinearGradient(
                      begin: Alignment.bottomCenter,
                        end: Alignment.topCenter,
                        colors: [
                          myColor.shade900,
                          myColor.shade500,
                          myColor.shade200
                        ]

                    )
                  ),
                ),
              );
            },

          ),
          AnimatedBuilder(
              animation: controller,
              builder: (context,child){
                return Positioned(
                    left: animation.value+MediaQuery.of(context).size.width/17,
                    bottom: 32,
                    child: Container(
                      width: 50,
                    height: 50,
                    decoration: BoxDecoration(
                      shape: BoxShape.circle,
                      gradient: RadialGradient(
                          colors: [

                            myColor.shade100,
                            myColor.shade700,
                          ]

                      )
                    ),
                    ));
              }),
          Row(
            children: List.generate(
              labels.length,
                  (index) {
                return GestureDetector(
                  onTap: () {
                    setState(() {
                      _selectedIndex = index;
                      animateBar(index);
                    });
                  },
                  child: AnimatedContainer(
                    color: Colors.transparent,
                    height: 89,
                    alignment: Alignment.bottomCenter,
                    duration: const Duration(milliseconds: 200),
                    width: screenSize.width * 0.25,
                    padding: EdgeInsets.only(bottom: _selectedIndex == index ? 37 :5),
                    child: Column(
                      // mainAxisSize: MainAxisSize.min,
                      mainAxisAlignment: MainAxisAlignment.end, // Vertically center-align the children
                      children: [
                        Icon(
                          icon[index],
                          color: Colors.white,
                          size: _selectedIndex == index ?35:25,
                        ),
                        Visibility(
                          visible: _selectedIndex!=index,
                          child: Text(
                            '${labels[index]}',
                            style: const TextStyle(
                              color: Colors.white ,
                            ),
                          ),
                        )
                      ],
                    ),
                  ),
                );
              },
            ),
          ),
        ],
      ),
    );





  }


}

class MyClipper extends CustomClipper<Path>{
  double x=0;

  MyClipper({required this.x }) ;

  @override
  Path getClip(Size size) {
    Path path =Path();
    path.moveTo(0+x, 0);
    path.quadraticBezierTo(size.width*.04+x, 0, size.width*.06+x, size.height*.25);
    path.quadraticBezierTo(size.width*.08+x, size.height*.5, size.width*.12+x, size.height*.5);
    path.quadraticBezierTo(size.width*.16+x, size.height*.5, size.width*.18+x, size.height*.25);
    path.quadraticBezierTo(size.width*.20+x, 0, size.width*.24+x, 0);
    path.lineTo(size.width, 0);
    path.lineTo(size.width, size.height);
    path.lineTo(0, size.height);
    path.lineTo(0, 0);
    return path;
  }

  @override
  bool shouldReclip(covariant CustomClipper<Path> oldClipper) {

    return true;
  }

}
